@@ -290,8 +290,8 @@ class CommandProcessor:
             # The result should be formatted context data
             if result and not result.startswith("❌"):
                 print(f"🔍 Context generated from {cmd_name}: command")
-                # Return False to indicate this is not a complete command - AI should process context
-                return False, result, messages
+                # ✅ FIX: Return True to continue chat, context data for interactive loop
+                return True, result, messages
             else:
                 print(f"❌ No context generated: {result}")
                 return True, None, messages
