@@ -100,7 +100,7 @@ def execute_prompt(prompt: str, model: str, use_local: bool = True) -> str:
                 if potential_command in available_commands:
                     command = command_registry.get_command(potential_command)
                     if command and getattr(command, 'is_context_provider', False):
-                        # This is a Context Provider Command - execute it independently of AI models
+                        # This is a Context Provider Command - generate context and inject into AI prompt
                         try:
                             context = {
                                 'current_model': model,
@@ -109,8 +109,18 @@ def execute_prompt(prompt: str, model: str, use_local: bool = True) -> str:
                             }
                             # Parse command arguments
                             args = [f"{potential_command}:"] + command_args.split() if command_args else [f"{potential_command}:"]
-                            result = command_registry.execute_command(potential_command, args, context)
-                            return result
+                            context_result = command_registry.execute_command(potential_command, args, context)
+                            
+                            print(f"🔍 Context generated from {potential_command}: command")
+                            
+                            # ✅ FIX: Inject context into prompt instead of returning directly
+                            if context_result and not context_result.startswith("❌"):
+                                # Create enhanced prompt with context
+                                enhanced_prompt = f"Context from {potential_command}: command:\n{context_result}\n\nUser: Please analyze the above context and provide insights."
+                                # Continue to AI model processing with enhanced prompt
+                                prompt = enhanced_prompt
+                            else:
+                                return f"❌ No context generated: {context_result}"
                         except Exception as e:
                             return f"❌ Error executing {potential_command}: command: {e}"
     
